//! Subcommand modules for the `spanr` binary.

pub mod combine;
pub mod compare;
pub mod convert;
pub mod cover;
pub mod coverage;
pub mod genome;
pub mod gff;
pub mod merge;
pub mod some;
pub mod span;
pub mod split;
pub mod stat;
pub mod statop;
